#!/usr/bin/env python
# coding=utf-8
#
# Copyright © Splunk, Inc. All Rights Reserved.

from __future__ import absolute_import, division, print_function, unicode_literals

import sys

from slim.utils import *
from slim.app import *
from slim.command import *


# Argument parser definition

parser = SlimArgumentParser(
    description='describe an app and its dependencies',
    epilog='This command assumes the app.manifest file is located at the root of the app source directory.'
)

parser.add_app_source()
parser.add_argument_help()
parser.add_repository()
parser.add_output_file(description='output of this command')


def main(args):
    describe(args.source, args.repository, args.output)


# pylint: disable=redefined-outer-name
def describe(source, repository=None, output=None, app_only=False):

    SlimLogger.step('Describing ' + encode_filename(source) + '...')

    # Default repository is set on slim_configuration
    if repository is None:
        repository = slim_configuration.repository_path

    # Load the app source form either a directory or tarball
    app_source = AppSource(source)
    SlimLogger.exit_on_error()

    # Describe the manifest and dependency graph

    # Load the app manifest file from the app source
    app_manifest = app_source.manifest
    SlimLogger.exit_on_error()

    # Describe each section of the manifest file (if we found no errors)
    app_manifest.describe(output)

    # Only describe the AppSource, not the dependencies
    if not app_only:

        # Create the dependency graph and validate it
        app_dependency_graph = AppDependencyGraph(app_source, repository)
        SlimLogger.exit_on_error()

        # Describe the dependency graph (if we found no errors)
        app_dependency_graph.describe(output)


if __name__ == '__main__':
    # noinspection PyBroadException
    try:
        main(parser.parse_args(sys.argv[1:]))
    except SystemExit:
        raise
    except:
        SlimLogger.fatal(exception_info=sys.exc_info())
